@@ -13,17 +13,16 @@
 ##############################################################################
 """Location support tests
 
-$Id: tests.py 104479 2009-09-24 11:19:54Z tlotze $
+$Id: tests.py 107006 2009-12-23 13:17:16Z kobold $
 """
 
+import doctest
 import unittest
-import zope.testing.doctest
-from zope.testing.doctestunit import DocTestSuite
 
 
 def test_suite():
     return unittest.TestSuite((
-        zope.testing.doctest.DocFileSuite('location.txt'),
-        DocTestSuite('zope.location.traversing'),
-        DocTestSuite('zope.location.pickling'),
-        ))
+        doctest.DocFileSuite('location.txt'),
+        doctest.DocTestSuite('zope.location.traversing'),
+        doctest.DocTestSuite('zope.location.pickling'),
+    ))
